@@ -4,6 +4,7 @@ from django.db.models.signals import post_save, pre_save
 from django.dispatch import receiver
 
 from ai_django_core.managers import GloballyVisibleQuerySet
+from ai_django_core.models import CommonInfo
 
 
 class MySingleSignalModel(models.Model):
@@ -12,6 +13,12 @@ class MySingleSignalModel(models.Model):
     objects = GloballyVisibleQuerySet.as_manager()
 
 
+class ForeignKeyRelatedModel(models.Model):
+    single_signal = models.ForeignKey(MySingleSignalModel, on_delete=models.CASCADE)
+
+    objects = GloballyVisibleQuerySet.as_manager()
+
+
 @receiver(pre_save, sender=MySingleSignalModel)
 def increase_value_no_dispatch_uid(sender, instance, **kwargs):
     instance.value += 1
@@ -32,3 +39,7 @@ def send_email(sender, instance, **kwargs):
                                  from_email='test@example.com',
                                  to=['random.dude@example.com'])
     msg.send()
+
+
+class CommonInfoBasedModel(CommonInfo):
+    value = models.PositiveIntegerField(default=0)
